@@ -10,7 +10,7 @@ class Person(KinopoiskObject):
 
     def __init__(self, **kwargs):
         super(Person, self).__init__(**kwargs)
-        from sources import PersonLink, PersonMainPage
+        from sources import PersonLink, PersonMainPage # import here for successful installing via pip
         self.register_source('link', PersonLink)
         self.register_source('main_page', PersonMainPage)
         self.posters = self.audience = []
